Learn R Programming

HierPortfolios (version 1.0.1)

DHRP_Portfolio: Constrained Hierarchical Risk Parity

Description

Performs the Constrained Hierarchical Risk Parity portfolio strategy proposed by Pfitzinger and Katzke (2019).

Usage

DHRP_Portfolio(covar, graph = FALSE, tau = 1, UB = NULL, LB = NULL)

Value

portfolio weights

Arguments

covar

Covariance matrix of returns. The covariance matrix will be transformed into correlation matrix and then into a distance matrix.

graph

To plot de dendrogram set this value to TRUE. By default this value is equal to FALSE.

tau

Parameter to evaluate asset similarity at the cluster edges. Default value is 1.

UB

Upper bound for weights. By default this value is equal to NULL

LB

Lower bound for weights. By default this value is equal to NULL

Author

Carlos Trucios and Moon Jun Kwon

References

Pfitzinger, J., and Katzke, N. A constrained hierarchical risk parity algorithm with cluster-based capital allocation (2019). Working Paper.

See Also

HCAA_Portfolio, HRP_Portfolio and HERC_Portfolio

Examples

Run this code
covar <- cov(mldp_returns)
DHRP_Portfolio(covar)

Run the code above in your browser using DataLab