powered by
Performs the Hierarchical Risk Parity portfolio proposed strategy by De Prado (2016). Several linkage methods for the hierarchical clustering can be used, by default the "single" linkage is used.
HRP_Portfolio(covar, linkage = "single", graph = FALSE)
portfolio weights
Covariance matrix of returns. The covariance matrix will be transformed into correlation matrix and then into a distance matrix.
Linkage method used in the hierarchical clustering. Allowed options are "single", "complete", "average" or "ward". Default option is "single".
To plot de dendrogram set this value to TRUE. By default this value is equal to FALSE.
Carlos Trucios
De Prado, Marcos Lopez. "Building diversified portfolios that outperform out of sample." The Journal of Portfolio Management 42.4 (2016): 59-69.
HCAA_Portfolio, HERC_Portfolio and DHRP_Portfolio
HCAA_Portfolio
HERC_Portfolio
DHRP_Portfolio
covar <- cov(mldp_returns) HRP_Portfolio(covar)
Run the code above in your browser using DataLab