Learn R Programming

HierPortfolios (version 1.0.1)

mldp_returns: Returns of 10 simulated assets.

Description

This dataset contains the simulated returns used in the numerical example of Marcos Lopez de Prado's paper, hence the name mldp_returns. The Python code used to reproduce this simulated data is kindly provided by the author in the supplementary material of his paper.

Arguments

References

De Prado, Marcos Lopez. "Building diversified portfolios that outperform out of sample." The Journal of Portfolio Management 42.4 (2016): 59-69.