powered by
Performs the Constrained Hierarchical Risk Parity portfolio strategy proposed by Pfitzinger and Katzke (2019).
DHRP_Portfolio(covar, graph = FALSE, tau = 1, UB = NULL, LB = NULL)
portfolio weights
Covariance matrix of returns. The covariance matrix will be transformed into correlation matrix and then into a distance matrix.
To plot de dendrogram set this value to TRUE. By default this value is equal to FALSE.
Parameter to evaluate asset similarity at the cluster edges. Default value is 1.
Upper bound for weights. By default this value is equal to NULL
Lower bound for weights. By default this value is equal to NULL
Carlos Trucios and Moon Jun Kwon
Pfitzinger, J., and Katzke, N. A constrained hierarchical risk parity algorithm with cluster-based capital allocation (2019). Working Paper.
HCAA_Portfolio, HRP_Portfolio and HERC_Portfolio
HCAA_Portfolio
HRP_Portfolio
HERC_Portfolio
covar <- cov(mldp_returns) DHRP_Portfolio(covar)
Run the code above in your browser using DataLab